.. webapi-error::
   :title: Enable Extension Failed
   :instance: djblets.webapi.errors.ENABLE_EXTENSION_FAILED

   There was an error enabling the extension. The details of the error
   will be included in the payload.
